@@ -1,6 +1,6 @@
 /* b-grok.c --- comma-v parsing
 
-   Copyright (C) 2010 Thien-Thi Nguyen
+   Copyright (C) 2010, 2011 Thien-Thi Nguyen
 
    This file is part of GNU RCS.
 
@@ -631,6 +631,12 @@ full (struct divvy *to, struct fro *f)
   if ((repo->strict = probe_keyword (g, &TINY (strict))))
     SEMI (g, strict);
 
+  if (probe_keyword (g, &TINY (integrity)))
+    {
+      maybe_read_atat (g, &repo->integrity);
+      SEMI (g, integrity);
+    }
+
   if (probe_keyword (g, &TINY (comment)))
     {
       maybe_read_atat (g, &repo->comment);
